@@ -5,12 +5,13 @@
 # __aml_shim__.py: AML wants to run a python script, so we use this to launch on shell/batch script
 import sys
 import os
-from xtlib import console
+
+# don't take on any XTLIB dependencies here (it may only be installed while processing the target setup cmds)
 
 # MAIN code
 args = sys.argv[1:]
-console.print("__aml_shim__: args=", args)
+print("__aml_shim__: args=", args)
 
 cmd = args[0]    # all are passed as a logical string (but args[1] is "1", so don't use that)
-console.print("__aml_shim__: about to run cmd=", cmd)
+print("__aml_shim__: about to run cmd=", cmd)
 os.system(cmd)
