@@ -26,7 +26,7 @@ from xtlib.report_builder import ReportBuilder
 from xtlib.helpers.feedbackParts import feedback as fb
 from xtlib.helpers.notebook_builder import NotebookBuilder
 
-from .backend_base import BackendBase
+from xtlib.backends.backend_base import BackendBase
 
 SECTION = "external-services"
 
