@@ -13,6 +13,7 @@ from xtlib.console import console
 
 from xtlib import utils
 from xtlib import errors
+from xtlib import cs_utils
 from xtlib import scriptor
 from xtlib import pc_utils
 from xtlib import run_errors
@@ -20,7 +21,7 @@ from xtlib import constants
 from xtlib import file_utils
 from xtlib import store_utils
 
-from .backend_interface import BackendInterface
+from xtlib.backends.backend_interface import BackendInterface
 
 class BackendBase(implements(BackendInterface)):
 
@@ -1167,6 +1168,8 @@ class BackendBase(implements(BackendInterface)):
 
         self.append(cmds, user_cmd)
 
+        self.append_title(cmds, "XT CONTROLLER EXITED:")
+
         self.export_now_to_var(cmds, "XT_POST_START_TIME")
 
         docker_cmd = args["docker_cmd"]
