@@ -74,7 +74,8 @@ class ITP(AzureML):
         cwd = "{}/.xt/cwd".format(job_home)
 
         # see if this helps our new blobfuse problem on ITP
-        mountbase = "$XT_ORIG_WORKDIR"
+        #mountbase = "$XT_ORIG_WORKDIR"    # using this path is ugly and long (causing mnt output problems in ITP as of Nov-08-2022)
+        mountbase = "/var/tmp/.xt"         # verified Nov-08-2022: this fixes the live output problem experienced by miniMnist.py
         tmpbase = job_home
 
         # we only do this once (for the first box/job)
@@ -122,6 +123,6 @@ class ITP(AzureML):
         #self.append(cmds, "cp -r -v /var/log {}".format(dest_dir))
         self.append(cmds, "cp -r -v $XT_ORIG_WORKDIR/logs {}".format(dest_dir))
 
-# API call
+    # API call
     def get_log_files_dir(self, args):
-        return "var/log/compute"
+        return "/var/log/compute"
