@@ -5,7 +5,7 @@
 # backend_singularity.py: support for running jobs under the Microsoft Singularity platform (similiar to AML and ITP)
 
 import os
-from tracemalloc import start
+import time
 import urllib.request
 
 from azureml.core import Environment, Experiment, ScriptRunConfig, Workspace
@@ -263,7 +263,15 @@ class Singularity(AzureML):
         FN_STDOUT2_LOG = "azureml-logs/70_driver_log.txt"
         FN_STD_OUT_TXT = "user_logs/std_out.txt"
 
-        run = self.get_node_run(service_node_info)
+        for r in range(3):
+            # try 3 times, then just bail
+            try:
+                run = self.get_node_run(service_node_info)
+                break
+            except BaseException as ex:
+                print("error during get_node_run(): {}".format(ex))
+                time.sleep(2)
+
         job_id = utils.safe_value(service_node_info, "job_id", service_node_info["aml_exper_name"].split("__")[3])
         node_id =  utils.safe_value(service_node_info, "node_id", "node0")
         workspace = service_node_info["ws"]
