@@ -298,9 +298,31 @@ class CmdCore():
         context.first_run_index = first_run_index
         context.last_run_index = last_run_index
 
+        # notification data from config file
+        context.config_events = dict(self.config.get("events"))
+        context.team_dict = self.config.get("team")
+
+        # expand config_event to include a "notify_count" property
+        for event in context.config_events.values():
+            event["notify_count"] = 0
+            event["max_notify_count"] = 1
+
+        # notification data from job
+        context.job_events = args["events"]
+        context.notify_list = args["notify"]
+
+        # add email/sms creds
+        context.email_cs = self.config.get("external-services", "xt-email", "connection-string")
+        context.email_from = self.config.get("external-services", "xt-email", "from")
+        context.sms_cs = self.config.get("external-services", "xt-sms", "connection-string")
+        context.sms_from = self.config.get("external-services", "xt-sms", "from")
+
         # only apply run delays for jobs with multiple runs
         context.max_delay = args["max_run_delay"] if total_run_count > 1 else 0
 
+        # limit time each node can run
+        context.max_minutes = args["max_minutes"] 
+
         # expand this on the compute node (where we know the node/run assignment in case of dynamic schedule)
         context.display_name = args["display_name"]
 
