@@ -22,13 +22,15 @@ from rpyc.utils.authenticators import SSLAuthenticator
 from xtlib.utils import log_info, log_title, log_info_to_text
 
 # xtlib 
+from xtlib import cmd_utils
 from xtlib import store_utils
 from xtlib.helpers.bag import Bag
 from xtlib.console import console
 from xtlib.run_info import RunInfo
 from xtlib.helpers import file_helper
-from xtlib.storage.store import store_from_context
 from xtlib.mirror_worker import MirrorWorker
+from xtlib.event_processor import EventProcessor
+from xtlib.storage.store import store_from_context
 from xtlib.hparams.hparam_search import HParamSearch
 from xtlib.helpers.stream_capture import StreamCapture
 
@@ -157,6 +159,7 @@ class XTController(rpyc.Service):
         self.ws_name = None
         self.node_restart = False
         self.app_start_str = utils.get_arrow_time_str()
+        self.event_processor = None
 
         is_on_aml_node = os.getenv("AZ_BATCH_TASK_ID")
         if is_on_aml_node:
@@ -302,6 +305,18 @@ class XTController(rpyc.Service):
                 log_info("removing store instance for thread=", thread_id)
                 del self.store_instances[thread_id]
         
+    def process_notification_events(self, current_event_when, run_name=None):
+        if self.job_events:
+
+            if not self.event_processor:
+                # JIT create
+                self.event_processor = EventProcessor(self.mrc_context.ws, self.job_id, self.node_index)
+
+            # create store on correct thread
+            store =  store_from_context(self.mrc_context)
+            
+            self.event_processor.process_notifications(store, self.mrc_context, current_event_when, run_name)
+
     def process_multi_run_context(self, multi_run_context_fn):
         # read the cmd and context from the file
 
@@ -328,6 +343,7 @@ class XTController(rpyc.Service):
         self.ws_name = context.ws
         self.job_id = context.job_id
         self.total_run_count = context.total_run_count
+        self.job_events = context.job_events
 
         self.first_run_index = context.first_run_index
         self.last_run_index = context.last_run_index
@@ -381,6 +397,8 @@ class XTController(rpyc.Service):
         log_info("calling job_node_start", self.job_id)
         db.job_node_start(self.ws_name, self.job_id, node_index=self.node_index, is_restart=self.node_restart)
 
+        self.process_notification_events("start_node")
+
         was_queued = []    # list of runs that were queued before we were restarted
 
         # queue the single or parent job in context
@@ -450,8 +468,8 @@ class XTController(rpyc.Service):
             try:
                 # delay between queue checks
                 time.sleep(2)
-
                 self.queue_check(1)
+
             except BaseException as ex:
                 logger.exception("Error in controller.thread_manager, ex={}".format(ex))
                 console.print("** Exception during queue_check(): ex={}".format(ex))
@@ -460,8 +478,20 @@ class XTController(rpyc.Service):
                 traceback.print_exc()
 
                 # give dev a chance to read the error before exiting (if viewing live log)
-                console.print("sleeping 30 secs before exiting...")
-                time.sleep(30)    
+                console.print("sleeping 15 secs before exiting...")
+                time.sleep(15)    
+
+                # shutdown app now
+                os._exit(1)
+
+            node_elapsed_mins = (time.time() - self.started)/60
+            if self.mrc_context.max_minutes and (node_elapsed_mins > self.mrc_context.max_minutes):
+                console.print("** Error: node elapsed_mins ({:.2f}) exceeded job's max_minutes ({:.2f})".format( \
+                    node_elapsed_mins, self.mrc_context.max_minutes))
+
+                # give dev a chance to read the error before exiting (if viewing live log)
+                console.print("sleeping 15 secs before exiting...", flush=True)
+                time.sleep(15)    
 
                 # shutdown app now
                 os._exit(1)
@@ -560,7 +590,7 @@ class XTController(rpyc.Service):
                 db_retries, storage_retries = run_errors.count_node_errors()
 
                 # log stats for job
-                db.job_node_exit(ws_id, job_id)
+                job_completed = db.job_node_exit(ws_id, job_id)
 
                 # log stats for node 
                 utils.log_info("NODE db_retries", db_retries)
@@ -569,6 +599,13 @@ class XTController(rpyc.Service):
                 db.node_end(ws_id, job_id, self.node_index, db_retries, 
                     storage_retries, self.app_start_str)
 
+                self.process_notification_events("end_node")
+
+                if job_completed:
+                    self.process_notification_events("end_job")
+
+
+
             else:
                 context = None
 
@@ -678,6 +715,8 @@ class XTController(rpyc.Service):
         return processed_entry
 
     def process_queue_entry(self, run_info):
+        log_info("process_queue_entry: run_info:", run_info)
+
         if run_info.parent_prep_needed:
 
             # run PARENT PREP script 
@@ -870,7 +909,7 @@ class XTController(rpyc.Service):
         log_info("run_index: " + str(run_index), "cmd: {}".format(cmd))
 
         # update context with new cmd
-        context.cmd_parts = utils.cmd_split(cmd)    
+        context.cmd_parts = cmd_utils.user_cmd_split(cmd)    
 
         store = self.get_store()
 
@@ -1035,6 +1074,8 @@ class XTController(rpyc.Service):
             if stop_controller:
                 self.stop_processing_runs = True
 
+        self.process_notification_events("end_run", run_info.run_name)
+
         log_info("end of", "exit handler")
 
     def on_connect(self, conn):
@@ -1508,6 +1549,9 @@ class XTController(rpyc.Service):
         return True
 
     def start_run_now(self, rundir, parts, cwd, fn_script, child_env, stdout_is_text, bufsize, run_info):
+
+        self.process_notification_events("start_run", run_info.run_name)
+
         if pc_utils.is_windows():
             # target must be a fully qualified name to work reliably
             fq = os.path.join(rundir, parts[0])
