@@ -562,13 +562,15 @@ def get_merged_config(create_if_needed=True, local_overrides_path=None, suppress
 
     # is there a GLOBAL config?
     fn_global = os.path.expanduser(os.getenv("XT_GLOBAL_CONFIG", "~/.xt/xt_config.yaml"))
+    fn_global = os.path.normcase(os.path.abspath(fn_global))
     if os.path.isfile(fn_global):    
         _apply_override(validator, config, schema, fn_schema, fn_global)
         fn_complete = fn_global
 
     # is there a LOCAL config?
     fn_local = local_overrides_path if local_overrides_path else constants.CONFIG_FN
-    if os.path.isfile(fn_local):    
+    fn_local = os.path.normcase(os.path.abspath(fn_local))
+    if os.path.isfile(fn_local) and fn_local != fn_global:    
         _apply_override(validator, config, schema, fn_schema, fn_local)
         fn_complete = fn_local
 
