@@ -612,6 +612,11 @@ class SearchHistory():
         else:
             self.load_runs_from_db()
 
+        # Check for the case of no finished runs.
+        if len(self.runs) == 0:
+            console.print("None of the runs in this HP search have completed successfully yet.")
+            return
+
         # Add the runs to a global runset, which will double as the sentinel of the runset list.
         global_runset = RunSet(0, None, None, None)
         for run in self.runs:
