@@ -13,6 +13,7 @@ import tempfile
 import numpy as np 
 
 import xtlib.xt_run as xt_run
+from xtlib import cs_utils
 from xtlib import report_builder
 from xtlib.client import Client
 from xtlib.runner import Runner
@@ -627,7 +628,7 @@ class ImplCompute(ImplBase):
     @argument("run-names", type="str_list", help="the list of run names to cancel")
     @option("workspace", default="$general.workspace", type=str, help="the workspace that contains the runs")
     @example(task="cancel run103 in curious workspace", text="xt cancel runs run103 --work=curious")
-    @command(kwgroup="cancel", help="cancels the specified run(s)")
+    @command(kwgroup="cancel", kwhelp="cancels active runs, jobs, or requests", help="cancels the specified run(s)")
     def cancel_run(self, run_names, workspace):
 
         runs_by_box = self.get_runs_by_box(run_names, workspace)
@@ -666,7 +667,7 @@ class ImplCompute(ImplBase):
     @flag("cancel", default=1, help="call the backend service to cancel the job")
     @flag("wrapup", default=1, help="wrapup the nodes and runs associated with the job")
     @example(task="cancel jobs job3 and job15", text="xt cancel job job3, job15")
-    @command(kwgroup="cancel", kwhelp="cancels active runs, jobs, or requests", help="cancels the specified jobs and their active or queued runs")
+    @command(kwgroup="cancel", help="cancels the specified jobs and their active or queued runs")
     def cancel_job(self, job_names, workspace, max_workers, cancel, wrapup):
 
         for job_id in job_names:
@@ -702,7 +703,7 @@ class ImplCompute(ImplBase):
     @argument("names", type="str_list", help="the names of the requests to be cancelled")
     @option("workspace", default="$general.workspace", help="the workspace that contains the requests")
     @example(task="cancel requests request3 and request5", text="xt cancel requests request3, request5")
-    @command(kwgroup="cancel", kwhelp="cancels jobs, runs, requests", help="cancels job submission requests (created by xt run --request)")
+    @command(kwgroup="cancel", help="cancels job submission requests (created by xt run --request)")
     def cancel_requests(self, names, workspace):
 
         filter_dict = {"request_id": {"$in": names}}
@@ -716,17 +717,21 @@ class ImplCompute(ImplBase):
                 self.store.update_request_status(record, "cancelled", username)
                 console.print("request cancelled: {}".format(name))
 
+                # notify requester (and cc-canceller)
+                requester = record["requested_by"]
+                self.send_cancel_email_to_approvers(name, requester, username)
+                console.print("cancellation sent (email/SMS) to requester: {}".format(requester))
+
             else:
                 console.print("request '{}' not pending; status: {}".format(name, status))
 
-    def send_email_to_requester(self, request_id, requester, approver, job_id):
+    def send_approval_email_to_requester(self, request_id, requester, approver, job_id):
         team_dict = self.config.get("team")
-        requester_contacts = team_dict[requester]["contact"]
-        approver_contacts = team_dict[approver]["contact"]
 
-        # for now, assume all entries in approver_contacts are valid email names 
-        # TODO: add support for SMS text to phone numbers
-        subject = "approved: {} --> {}".format(request_id, job_id)
+        requester_contacts = cs_utils.get_contacts(team_dict, requester)
+        approver_contacts, approver_usernames = cs_utils.get_approvers(team_dict)
+        
+        subject = "{} APPROVED: {}".format(request_id, job_id)
 
         # make body HTML 
         body = ""
@@ -736,10 +741,33 @@ class ImplCompute(ImplBase):
         sent = False
 
         try:
-            utils.send_email(self.config, requester_contacts, approver_contacts, subject, body)
+            cs_utils.send_to_contacts_from_config(self.config, requester_contacts, approver_contacts, subject, body)
             sent = True
         except BaseException as ex:
-            console.print("email send failed: ex: {}".format(ex))
+            console.print("email/SMS send failed: ex: {}".format(ex))
+
+    def send_cancel_email_to_approvers(self, request_id, requester, canceller):
+        team_dict = self.config.get("team")
+
+        requester_contacts = cs_utils.get_contacts(team_dict, requester)
+        canceller_contacts = cs_utils.get_contacts(team_dict, canceller)
+        approver_contacts, approver_usernames = cs_utils.get_approvers(team_dict)
+
+        cc_list = cs_utils.combine_contacts(requester_contacts, canceller_contacts)
+        
+        subject = "job request CANCELLED: {}".format(request_id)
+
+        # make body HTML 
+        body = ""
+        body += "<b>job submission request:</b> {}".format(request_id)
+        body += "<br><b>cancelled by:</b> {}".format(canceller)
+        sent = False
+
+        try:
+            cs_utils.send_to_contacts_from_config(self.config, approver_contacts, cc_list, subject, body)
+            sent = True
+        except BaseException as ex:
+            console.print("email/SMS send failed: ex: {}".format(ex))
 
     #---- APPROVE command ----
     @argument("names", type="str_list", help="the names of the requests to be approved")
@@ -774,8 +802,8 @@ class ImplCompute(ImplBase):
                 self.store.database.update_requests_record(workspace, name, record)
 
                 requester = record["requested_by"]
-                self.send_email_to_requester(name, requester, username, job_id)
-                console.print("approval emailed to requester: {}".format(requester))
+                self.send_approval_email_to_requester(name, requester, username, job_id)
+                console.print("approval sent (email/SMS) to requester: {}".format(requester))
 
             else:
                 console.print("request '{}' not pending; status: {}".format(name, status))
@@ -848,7 +876,7 @@ class ImplCompute(ImplBase):
     @hidden("username", default="$general.username", help="the username to log as the author of this run")
     @option("workspace", default="$general.workspace", help="the workspace to cancel runs in")
     @example(task="cancel all runs for current user on Philly", text="xt cancel all philly")
-    @command(kwgroup="cancel", help="cancels all queued/active runs on the specified compute target")
+    @command(kwgroup="cancel", kwhelp="cancels jobs, runs, requests", help="cancels all queued/active runs on the specified compute target")
     def cancel_all(self, target, username, workspace):
 
         backend = self.core.create_backend(target, username=username)
@@ -1006,6 +1034,7 @@ class ImplCompute(ImplBase):
     @option("escape", type=int, default=0, help="breaks out of attach or --monitor loop after specified # of seconds")
     @hidden("env-vars", default="$general.env-vars", help="the environment variable to be passed to the run when it is launched")
     @hidden("evaluation-interval", default="$early-stopping.evaluation-interval", type=int, help="the frequencency (# of metric logs) for testing the policy")
+    @option("events", type="str_list", help="the list of events used to generate notifications for this job")
     @option("experiment", default="$general.experiment", type=str, help="the name of the experiment to create this run under")
     @option("fake-error-percent", default="$database.fake-error-percent", type=float, help="for testing only: the percentage of database calls to fail")
     @flag("fake-submit", help="when True, we skip creation of job and runs and the submit (used for internal testing)")
@@ -1044,6 +1073,7 @@ class ImplCompute(ImplBase):
     @option("node-repeat", type=int, help="the number of times to repeat each hyperparameter set on each node")
     @hidden("node-script-path", type=str, default="$code.node-script-path", help="relative path to script on computing node")
     @option("nodes", type=int, help="the number of normal (non-preemptable) nodes to allocte for this run")
+    @option("notify", type="str_list", help="the list of users to notify for notifications generated by this job")
     @option("nowrap", type=bool, help="when true, don't generate a wrapper script for XT setup; run user script directly")
     @option("num-dgd-seeds", type=int, default="$hyperparameter-search.num-dgd-seeds", help="the number of random HP configurations used to initialize the DGD search")
     @hidden("option-prefix", default="$hyperparameter-search.option-prefix", help="the prefix to be used for specifying hyperparameter options to the script")
