@@ -74,7 +74,7 @@ class ImplHelp(ImplBase):
                         name = kwgroup
                         help_text = fi["kwhelp"]
                         if not help_text:
-                            errors.internal_error("kwhelp must be defined for this first kwgroup member: " + fi[name_field])
+                            errors.internal_error("kwhelp must be defined for this LAST kwgroup member: " + fi[name_field])
 
                 if include_type:
                     fmt = "  " + prefix + "{:<"  + str(max_name_len) + "}    {:<"  + str(max_type_len) + "}    {}"
