@@ -119,21 +119,21 @@ class ImplShared():
         self.config = None
         self.store = StoreOnDemand()
 
-    def expand_xt_symbols(self, args):
-        for i, arg in enumerate(args):
-            
-            if "$lastrun" in arg:
-                last_run = xt_dict.get_xt_dict_value("last_run", "run0")
-                args[i] = arg.replace("$lastrun", last_run)
+    def expand_xt_symbols(self, cmd):
 
-            if "$lastjob" in arg:
-                last_job = xt_dict.get_xt_dict_value("last_job", "job0")
-                args[i] = arg.replace("$lastjob", last_job)
+        if "$lastrun" in cmd:
+            last_run = xt_dict.get_xt_dict_value("last_run", "run0")
+            cmd = cmd.replace("$lastrun", last_run)
 
-            if "$username" in arg:
-                username = pc_utils.get_username()
-                args[i] = arg.replace("$username", username)
+        if "$lastjob" in cmd:
+            last_job = xt_dict.get_xt_dict_value("last_job", "job0")
+            cmd = cmd.replace("$lastjob", last_job)
 
+        if "$username" in cmd:
+            username = pc_utils.get_username()
+            cmd = cmd.replace("$username", username)
+
+        return cmd
 
     def init_config(self, fn_local_config, args=None):
         self.config = xt_config.get_merged_config(local_overrides_path=fn_local_config)
