@@ -1421,9 +1421,9 @@ class PlotBuilder():
             user_columns.insert(0, "hp_set")
 
         # print common hyperparameters on top of report
-        if common and self.hp_set_formatter.hp_common_set:
+        if common and self.hp_set_formatter.hp_sets_processed:
             console.print("\nCommon hyperparameters:")
-            for hp,value in self.hp_set_formatter.hp_common_set.items():
+            for hp,value in self.hp_set_formatter.hp_unchanged_dict.items():
                 console.print("  {}: {}".format(hp, value))
             console.print("")
 
