@@ -3,6 +3,7 @@
 # Licensed under the MIT license.
 #
 # remote_psm_client.py: talk to Pool State Mgr running on local machine
+from concurrent.futures import process
 import os
 import time
 import uuid
@@ -54,7 +55,7 @@ class RemotePsmClient():
         keyfile = os.path.expanduser(constants.LOCAL_KEYPAIR_PRIVATE)
 
         self.ssh_client.connect(hostname=self.box_addr, username=self.box_user, 
-            key_filename=keyfile, look_for_keys=True)
+            key_filename=keyfile, look_for_keys=True,  banner_timeout=200)
 
         self.ftp_client = self.ssh_client.open_sftp()
 
@@ -107,14 +108,30 @@ class RemotePsmClient():
         
         return entries, current
 
-    def run_cmd(self, cmd):
+    def run_cmd_core(self, cmd):
         stdin, stdout, stderr = self.ssh_client.exec_command(cmd)
 
+        # read both output streams
         stdout_text = stdout.read().decode()
         stderr_text = stderr.read().decode()
         #console.print("cmd: {}\nstdout: {}\nstderr: {}".format(cmd, stdout_text, stderr_text))
 
-        return stdout_text
+        return stdout_text, stderr_text
+
+    def run_cmd(self, cmd):
+        stdin, stdout, stderr = self.ssh_client.exec_command(cmd)
+
+        # read both output streams
+        stdout_text = stdout.read().decode()
+        stderr_text = stderr.read().decode()
+        #console.print("cmd: {}\nstdout: {}\nstderr: {}".format(cmd, stdout_text, stderr_text))
+
+        combined_text = stdout_text 
+        if stdout_text and stderr_text:
+            combined_text += "\n"
+        combined_text += stderr_text
+
+        return combined_text
 
     def _get_psm_process_id(self):
         # current code only supports linux as remote
@@ -252,7 +269,7 @@ class RemotePsmClient():
             p = self._get_psm_process_id()
             if p:
                 ssh_cmd = "kill -kill {}".format(p)
-                self.run_cmd(ssh_cmd)
+                output_text = self.run_cmd(ssh_cmd)
             start_needed = True
 
         if start_needed:
@@ -331,7 +348,7 @@ class RemotePsmClient():
 
         fn_queue_entry = file_utils.path_join(self.psm_queue_path, fn_entry, for_windows=False)
         ssh_cmd = "ls -lt " + fn_queue_entry
-        result = self.run_cmd(ssh_cmd)
+        result, error = self.run_cmd_core(ssh_cmd)
 
         if result and fn_entry in result:
             status = "queued"
@@ -370,11 +387,19 @@ class RemotePsmClient():
         else:
             text = self.get_running_entry_name()
             if text == fn_entry:
+                
                 # entry might be running; is the controller active?
                 process_id = self._get_controller_process()
+                console.print("PSM cancel: foud running entry={}, process_id={}".format(text, process_id))
+
                 if process_id:
-                    ssh_cmd = "kill -kill {}".format(process_id)
-                    self.run_cmd(ssh_cmd)
+                    if self.box_is_windows:
+                        ssh_cmd = "kill -kill {}".format(process_id)
+                    else:
+                        ssh_cmd = "sudo kill -kill {}".format(process_id)
+                    output_text = self.run_cmd(ssh_cmd)
+                    
+                    console.print("PSM cancel: kill cmd result: {}".format(output_text))
                     cancelled = True
 
         return cancelled, status
@@ -383,10 +408,10 @@ class RemotePsmClient():
         '''
         Description:
             Each SSH call to read a file takes about 1.5 secs (too long), so
-            we instead leverage   
+            we instead leverage FTP for reading/writing files  
         '''
-        fn_entry_base = os.path.splitext(fn_entry)[0]
-        fn_log = os.path.join(self.psm_logdir, fn_entry_base + ".log")
+        #fn_entry_base = os.path.splitext(fn_entry)[0]
+        fn_log = os.path.join(self.psm_logdir, "stdboth.txt")
 
         new_bytes = self.read_file(fn_log, start_offset, end_offset)
         return new_bytes
