@@ -14,6 +14,7 @@ from xtlib.helpers.scanner import Scanner
 
 from xtlib import utils
 from xtlib import errors
+from xtlib import cmd_utils
 from xtlib import run_helper
 from xtlib import job_helper
 
@@ -1269,10 +1270,14 @@ class Dispatcher():
 
         return new_text
 
-    def extract_template_option(self, args):
+    def extract_template_option(self, cmd):
+        '''
+        parse the --template option for the "xt view tensorboard" cmd
+        '''
         template_option = None
         new_args = []
         parsing_template = False
+        args = cmd_utils.xt_cmd_split(cmd)
 
         for arg in args:
 
@@ -1295,8 +1300,9 @@ class Dispatcher():
             else:
                 new_args.append(arg)
 
+        new_cmd = cmd_utils.join_args(new_args)
 
-        return template_option, new_args
+        return template_option, new_cmd
         
     def get_layers_dest(self, options):
         dest = None
@@ -1308,34 +1314,35 @@ class Dispatcher():
 
         return dest
 
-    def dispatch(self, args, is_rerun=False, capture_output=False, raise_syntax_exception=False):
+    def dispatch(self, text, is_rerun=False, capture_output=False, raise_syntax_exception=False):
         self.raise_syntax_exception = raise_syntax_exception
         
         # be sure to reset this for each parse (for multi-command XT sessions)
         global explicit_options
         explicit_options = {}
 
-        # extract the template option since it has curly brackets that are not converted to quotes
-        template_option, args = self.extract_template_option(args)
+        if "--tem" in text:
+            # extract the --template option (xt view tensorboard) since it has curly brackets that are not converted to quotes
+            template_option, text = self.extract_template_option(text)
 
-        # join args together to get original cmd line (but without quotes)
-        text = " ".join(args)
+            # NOTE: Windows/Linux command line parsers typically strip away quotes found in cmd
+            # XT allows allows the user to use {} as a 2nd set of quotes around complex values (that won't get stripped away)
+            text = self.replace_curlies_with_quotes(text)
 
-        # NOTE: Windows/Linux command line parsers typically strip away quotes found in cmd
-        # XT allows allows the user to use {} as a 2nd set of quotes around complex values (that won't get stripped away)
-        text = self.replace_curlies_with_quotes(text)
+            # add back template option
+            if template_option:
+                text += " " + template_option
 
-        # add back template option
-        if template_option:
-            text += " " + template_option
-
-        console.diag("\nADJUSTED cmd={}".format(text))
+            console.diag("\nADJUSTED cmd={}".format(text))
+        elif "{" in text:
+            # replace curly brackets with quotes
+            text = text.replace("{", "\"").replace("}", "\"")
 
         self.dispatch_cmd = text
 
+
         scanner = Scanner(text)
         tok = scanner.scan()
-        #console.print("first tok=", tok)
 
         # process any ROOT FLAGS
         if root_cmd_info:
