@@ -996,6 +996,9 @@ class ReportBuilder():
             user_col = col
             user_fmt = None
 
+            if col.startswith("tags.priority"):
+                aa = 9
+
             if self.user_col_args:
                 user_args = self.get_user_col_arg(col)
                 if user_args:
@@ -1006,7 +1009,7 @@ class ReportBuilder():
 
             col_width = len(user_col)
             #console.print("col=", col, ", col_width=", col_width)
-            value_type = str
+            value_type = None
             is_numeric = False
             first_value = True
 
@@ -1018,9 +1021,6 @@ class ReportBuilder():
                 try:
                     value = record[col]
 
-                    if col == "hp_set":
-                        dummy = 0
-
                     # special formatting for time values
                     if col in duration_col_names:
                         value = self.format_duration(value, col, record)
@@ -1034,12 +1034,12 @@ class ReportBuilder():
                             value = value.format('YYYY-MM-DD @HH:mm:ss')
 
                     # for sql, convert float types that are really integer values to int types
-                    if isinstance(value, float) and value == int(value) and user_fmt is None and value_type is str:
+                    if isinstance(value, float) and value == int(value) and user_fmt is None and value_type in [str, int]:
                         value = int(value)
                     # elif isinstance(value, float) and value_type is int:
                     #     value = int(value)
 
-                    elif isinstance(value, str) and value.isnumeric():
+                    elif value_type is None and isinstance(value, str) and value.isnumeric():
                         # handle cases where int was logged incorrectly as a string
                         value = int(value)
 
@@ -1360,28 +1360,7 @@ class ReportBuilder():
                 value = time.time() - start_value
                 ongoing = True
 
-        if not value:
-            value = ""
-        else:
-            secs = float(value)   # in case its a string
-            secs_per_day = 60*60*24
-            days = secs/secs_per_day
-            plus = "+" if ongoing else ""
-
-            if days >= 1:
-                value = "{}{:,.1f} days".format(plus, days)
-            else:
-                hrs = days*24
-                if hrs >= 1:
-                    value = "{}{:,.1f} hrs".format(plus, hrs)
-                else:
-                    mins = hrs*60
-                    if mins > 1:
-                        value = "{}{:,.1f} mins".format(plus, mins)
-                    else:
-                        secs = mins*60
-                        value = "{}{:,.1f} secs".format(plus, secs)
-
+        value = utils.friendly_duration_format(value, ongoing)
         return value
 
     def get_report_color(self, config_section, config_name):
@@ -1469,6 +1448,7 @@ class ReportBuilder():
             if catch_exception:
                 try:
                     for col_info in col_infos:
+
                         first_col, text = self.format_col_to_text(record, col_info, first_col, text, max_fixed_length, 
                             float_precision, significance, col_space, right_align_num_cols, 
                             duration_col_names, time_col_names)
@@ -1483,6 +1463,7 @@ class ReportBuilder():
             else:
 
                 for col_info in col_infos:
+                    
                     first_col, text = self.format_col_to_text(record, col_info, first_col, text, max_fixed_length, 
                         float_precision, significance, col_space, right_align_num_cols, 
                         duration_col_names, time_col_names)
@@ -1520,15 +1501,15 @@ class ReportBuilder():
         col = col_info["name"]
         value_type = col_info["value_type"]
 
+        if col.startswith("metrics.epoch"):
+            aa = 9
+
         right_align = right_align_num_cols and (col_info["is_numeric"] or user_fmt or \
-            col_info["value_type"] == bool) or col in duration_col_names
+            value_type == bool) or col in duration_col_names
 
         col_width = col_info["col_width"]
         align = ">" if right_align else "<"
 
-        if col == "hp_set":
-            dummy = 33
-
         if not col in record:
             # not all records define all columns
             str_fmt = "{:" + align + str(col_width)  + "." + str(col_width) + "s}"
@@ -1539,7 +1520,7 @@ class ReportBuilder():
             # special handling for int values that were logged as floats
             # if isinstance(value, float) and value_type is int:
             #     value = int(value)
-            if isinstance(value, str) and value.isnumeric():
+            if value_type is int and value is not None:     # isinstance(value, str) and value.isnumeric():
                 # handle cases where int was logged incorrectly as a string
                 value = int(value)
 
