@@ -22,6 +22,7 @@ from xtlib import impl_storage
 #from xtlib.storage.store import Store, store_from_context
 from xtlib.console import console
 from xtlib.impl_shared import StoreOnDemand
+from xtlib.event_processor import EventProcessor
 from xtlib.helpers.xt_config import get_merged_config
 from xtlib.helpers.key_press_checker import KeyPressChecker
 
@@ -52,6 +53,8 @@ class Run():
         self.supress_normal_output = supress_normal_output
         self.user_requests = []
         self.closed = False
+        self.event_processor = None
+        self.job_events = None
 
         # TODO: find/remove any unneeded AML logic (leftover from XT original-approach AML support)
         self.is_aml = None
@@ -117,6 +120,7 @@ class Run():
                 self.store_creds = json.loads(self.store_creds)
 
             provider_code_path = os.getenv("XT_STORE_CODE_PATH")
+            self.job_events = self.context.job_events
 
         run_cache_dir = None
         self.config = config
@@ -456,6 +460,18 @@ class Run():
                         self.test_writer2.add_scalar(name, value, global_step=step_num)
                 self.test_writer2.flush()
 
+        if self.store and self.xt_logging:
+            self.process_notification_events("log_run")
+
+    def process_notification_events(self, current_event_when):
+        if self.job_events:
+
+            if not self.event_processor:
+                # JIT create
+                self.event_processor = EventProcessor(self.context.ws, self.job_id, self.context.node_index)
+
+            self.event_processor.process_notifications(self.store, self.context, current_event_when, self.run_name)
+
     def log_event(self, event_name, data_dict):
         if self.store and self.xt_logging:
             self.store.log_run_event(self.ws_name, self.run_name, event_name, data_dict)
