@@ -57,7 +57,7 @@ class RunInfo():
         self.parent_prep_needed = parent_prep_needed      # when True, must run parent prep script before running first child
         self.console_fn = None
         self.process_was_created = False
-        self.mirror_worker = None
+        self.mirror_workers = None
         self.mirror_close_func = mirror_close_func
         self.job_id = context.job_id
         self.exper_name = context.exper_name
@@ -73,12 +73,10 @@ class RunInfo():
         console_fn = os.path.expanduser(console_fn)
         self.console_fn = console_fn
 
-        if os.path.exists(console_fn):
-            os.remove(console_fn)
-
+        # if os.path.exists(console_fn):
+        #     os.remove(console_fn)
         file_utils.ensure_dir_exists(file=console_fn)
 
-
     def process_run_output(self, text_msg, run_info_is_locked=False):
 
         # if self.context.scrape:
@@ -88,10 +86,17 @@ class RunInfo():
         #         return
 
         # let run_info keep recent output for new clients
-        self.update_recent_output(text_msg)
+        #self.update_recent_output(text_msg)
+
+        # append to output file (open/close file each time to ensure it is written to local file)
 
-        # append to output file
         if self.console_fn:
+            if os.path.isdir(self.console_fn):
+                console.print("INTERNAL ERROR: dir found at: {}", self.console_fn)
+                console.print("files in dir: {}".format(os.listdir(self.console_fn)))
+                os.rmdir(self.console_fn)
+                console.print("dir removed")
+
             with open(self.console_fn, "a") as tfile:
                 tfile.write(text_msg)
 
@@ -155,10 +160,10 @@ class RunInfo():
 
         return index
 
-    def update_recent_output(self, msg):
-        self.recent_output.append(msg)
-        if len(self.recent_output) > self.max_recent:
-            self.recent_output = self.recent_output[10:]        # drop oldest 10 lines
+    # def update_recent_output(self, msg):
+    #     self.recent_output.append(msg)
+    #     if len(self.recent_output) > self.max_recent:
+    #         self.recent_output = self.recent_output[10:]        # drop oldest 10 lines
 
     def wrapup_parent_prep_run(self):
         context = self.context
@@ -168,9 +173,9 @@ class RunInfo():
         '''wrap-up the run (logging, capture)'''
         #console.print("run_wrapup, self.killed_for_restart={}".format(self.killed_for_restart))
         
-        log_info("run_wrapup: mirror_worker", mirror_worker)
-        if self.mirror_worker:
-            self.mirror_close_func(self)
+        log_info("run_wrapup: mirror_workers", self.mirror_workers)
+        if self.mirror_workers:
+                self.mirror_close_func(self)
 
         context = self.context
         run_name = self.run_name
@@ -186,13 +191,14 @@ class RunInfo():
             log_info("runinfo.repeat", self.repeat)
 
             log_info("calling WRAPUP_RUN", self.run_name)
+            log_upload_files = context.log_file_uploads
 
             store.wrapup_run(context.ws, run_name, context.aggregate_dest, context.dest_name, 
                 status=self.status, exit_code=self.exit_code, primary_metric=context.primary_metric, 
                 maximize_metric=context.maximize_metric, report_rollup=context.report_rollup, rundir=self.rundir, 
                 after_files_list=context.after_files_list, after_omit_list=context.after_omit_list, log_events=context.log, 
                 capture_files=context.after_upload, job_id=self.job_id, is_parent=self.is_parent, node_id=self.node_id, 
-                run_index=self.run_index, start_time=self.started)
+                run_index=self.run_index, start_time=self.started, log_upload_files=log_upload_files)
 
     def set_status(self):
         if self.killing:
