@@ -22,6 +22,8 @@ from xtlib.helpers import file_helper
 from xtlib.helpers.scanner import Scanner
 from xtlib.hparams.hp_client import HPClient
 from xtlib.helpers.feedbackParts import feedback as fb
+from xtlib.event_processor import get_ids_from_python_expression
+
 
 from xtlib import qfe
 from xtlib import utils
@@ -29,7 +31,9 @@ from xtlib import errors
 from xtlib import capture
 from xtlib import xt_dict
 from xtlib import pc_utils
+from xtlib import cs_utils
 from xtlib import scriptor
+from xtlib import cmd_utils
 from xtlib import constants
 from xtlib import file_utils
 from xtlib import job_helper
@@ -80,7 +84,7 @@ class Runner():
 
         if target_args:
             # split on unquoted spaces
-            arg_parts = utils.cmd_split(target_args)
+            arg_parts = cmd_utils.user_cmd_split(target_args)
             cmd_parts += arg_parts
 
         if target_file == "docker":
@@ -705,20 +709,15 @@ class Runner():
         console.diag("after create local snapshot")
         return script_dir
 
-    def send_email_to_approvers(self, request_id, requested_by, description, target, nodes, runs, cmd):
+    def send_to_approvers(self, request_id, requested_by, description, target, nodes, runs, cmd):
         team_dict = self.config.get("team")
-        approver_dict = {key: md for key, md in team_dict.items() if utils.safe_value(md, "approver")}
-        approver_usernames = list(approver_dict)
-        approver_contacts = [md["contact"] for md in approver_dict.values()]
 
-        requested_by_contacts = team_dict[requested_by]["contact"]
-
-        # flatten list of lists
-        approver_contacts = [item for sublist in approver_contacts for item in sublist]
+        requested_by_contacts = cs_utils.get_contacts(team_dict, requested_by)
+        approver_contacts, approver_usernames = cs_utils.get_approvers(team_dict)
 
         # for now, assume all entries in approver_contacts are valid email names 
         # TODO: add support for SMS text to phone numbers
-        subject = "job submission request: {}".format(request_id)
+        subject = "job submission REQUESTED: {}".format(request_id)
 
         # make body HTML 
         store_name = self.config.get("store")
@@ -738,10 +737,10 @@ class Runner():
         sent = False
 
         try:
-            utils.send_email(self.config, approver_contacts, requested_by_contacts, subject, body)
+            cs_utils.send_to_contacts_from_config(self.config, approver_contacts, requested_by_contacts, subject, body)
             sent = True
         except BaseException as ex:
-            console.print("email send failed: ex: {}".format(ex))
+            console.print("email/SMS failed: ex: {}".format(ex))
 
         return approver_usernames, sent
 
@@ -787,12 +786,12 @@ class Runner():
         console.print("  code snapshot created: {:,} files (zipped to: {:,.2f} MB, stored: {})".format(file_count, zipped_mb, blob_fn))
         #console.print("  zipped & written to blob storage: {}".format(blob_fn))
 
-        # send email to approver(s)
-        approvers, sent = self.send_email_to_approvers(request_id, username, description, target, nodes, runs, run_cmd)
+        # send email/sms to approver(s)
+        approvers, sent = self.send_to_approvers(request_id, username, description, target, nodes, runs, run_cmd)
 
         # final message to requesting user
         if sent:
-            console.print("  request emailed to approvers: {}".format(", ".join(approvers)))
+            console.print("  request sent (email/SMS) to approvers: {}".format(", ".join(approvers)))
 
     def process_run_command(self, args):
         self.args = args
@@ -809,6 +808,43 @@ class Runner():
 
         return result
 
+    def validate_col_name(self, col):
+        if "." in col:
+            prefix, col_name = col.split(".")
+            if not prefix in ["metrics", "hparams"]:
+                errors.user_error("unrecognized prefix on column name: {}".format(col))
+
+    def validate_event(self, event_name, event):
+        condition = utils.safe_value(event, "if")
+        if condition:
+            # validate python expression
+            try:
+                id_list = get_ids_from_python_expression(condition)
+                for id in id_list:
+                    self.validate_col_name(id)
+
+            except BaseException as ex:
+                console.print("invalid condition syntax: '{}' in event '{}'".format(condition, event_name))
+                raise ex
+
+        report = utils.safe_value(event, "report")
+        if report:
+            # validate col names (at a high level)
+            for col in report:
+                self.validate_col_name(col)
+
+    def validate_nodify(self, notify_list):
+        team_dict = self.config.get("team")
+
+        for user in notify_list:
+            if not user in team_dict:
+                errors.user_error("notify user not found in teams dictionary: {}".format(user))
+
+            user_dict = team_dict[user]
+            if not "contact" in user_dict:
+                errors.user_error("notify user does not have 'contact' entry in teams dictionary: {}".format(user))
+
+
     def create_job(self, args):
 
         # ensure workspace exists
@@ -949,6 +985,21 @@ class Runner():
         keep_name = False  # args['keep_name']
         is_distributed = args['distributed']
         direct_run = args["direct_run"]
+        events = args["events"]
+        notify = args["notify"]
+
+        if events:
+            config_events = self.config.get("events")
+
+            for event_name in events:
+                if not event_name in config_events:
+                    errors.user_error("specified event not found in events dictionary of xt_config file: {}".format(event_name))
+
+                event = config_events[event_name]
+                self.validate_event(event_name, event)
+
+        if notify:
+            self.validate_notify(notify)
 
         # CREATE JOB (in database and blobs) to hold all runs
         if fake_submit:
@@ -1501,7 +1552,7 @@ class Runner():
         return hparams if hparams else None
 
     def fixup_script_in_cmd(self, cmd, node_script_path):
-        cmd_parts = utils.cmd_split(cmd)
+        cmd_parts = cmd_utils.user_cmd_split(cmd)
         
         self.adjust_script_dir(cmd_parts, node_script_path)
 
@@ -1756,7 +1807,7 @@ class Runner():
             console.print()   
 
         # finally, package info into run_specs to make info easier to pass thru various APIs
-        new_cmd_parts = utils.cmd_split(new_run_cmd)
+        new_cmd_parts = cmd_utils.user_cmd_split(new_run_cmd)
         run_specs = {"cmd_parts": new_cmd_parts, "run_script": run_script, "run_cmd": new_run_cmd, "parent_script": parent_script}
 
         return cmds, runsets, run_count, repeat_count, run_specs, using_hp, using_aml_hparam, sweeps_text, search_style
