@@ -538,50 +538,6 @@ def init_logging(fn, logger, title):
     logger.info("---------------------------")
     logger.info("new {} started".format(title))
 
-def cmd_split(cmd):
-    # split on spaces, unless protected by quotes or []
-    parts = []
-
-    part = ""
-    protector = None
-
-    for ch in cmd:
-        if protector:
-            # spaces are protected
-            part += ch
-            if ch == protector:
-                protector = None
-        else:
-            # spaces are separators
-            if ch == " ":
-                parts.append(part)
-                part = ""
-            else:
-                part += ch
-                if ch in ["'", '"']:
-                    protector = ch
-                elif ch == "[":
-                    protector = "]"
-
-    # add last part, if any
-    if part:
-        parts.append(part)
-
-    # cleanup parts
-    cmd_parts = []
-
-    for i, part in enumerate(parts):
-        part = part.strip()
-        if part:
-            if part.startswith("'") and part.endswith("'"):
-                part = part[1:-1]
-            elif part.startswith('"') and part.endswith('"'):
-                part = part[1:-1]
-
-            cmd_parts.append(part)
-
-    return cmd_parts
-
 def wildcard_to_regex(text):
     text2 = text.replace(".", "\\.")
     text3 = text2.replace("*", ".*")
@@ -688,7 +644,7 @@ def log_title(title, double=False):
 
 add_time_to_log_info = False
 
-def log_info(title, value):
+def log_info(title, value=None):
     if pc_utils.is_compute_node():
         title = (title + ":").ljust(25)
 
@@ -893,55 +849,28 @@ def debug_path(path):
 
         path = os.path.dirname(path)
 
-def send_email_via_outlook(to_list, cc_list, subject, body):
-    '''
-    Pro's:
-        - quick to send
-        - recognized sender
-        - shows up an internal (not flagged EXTERNAL)
-        
-    Con's:
-        - requires user to have Outlook installed
-        - user cannot launch XT from admin command window
-    '''
-    import win32com.client as win32
+def friendly_duration_format(value, ongoing):
+    
+    if not value:
+        value = ""
+    else:
+        secs = float(value)   # in case its a string
+        secs_per_day = 60*60*24
+        days = secs/secs_per_day
+        plus = "+" if ongoing else ""
 
-    outlook = win32.Dispatch('outlook.application')
-    mail = outlook.CreateItem(0)
+        if days >= 1:
+            value = "{}{:,.1f} days".format(plus, days)
+        else:
+            hrs = days*24
+            if hrs >= 1:
+                value = "{}{:,.1f} hrs".format(plus, hrs)
+            else:
+                mins = hrs*60
+                if mins > 1:
+                    value = "{}{:,.1f} mins".format(plus, mins)
+                else:
+                    secs = mins*60
+                    value = "{}{:,.1f} secs".format(plus, secs)
 
-    mail.To = ";".join(to_list)
-    mail.Cc = ";".join(cc_list)
-    mail.Subject = subject
-    mail.Body = body
-    mail.HTMLBody = body
-
-    # To attach a file to the email (optional):
-    # attachment  = "Path to the attachment"
-    # mail.Attachments.Add(attachment)
-
-    mail.Send()
-
-def send_email(config, to_list, cc_list, subject, body):
-    '''
-    Pro's:
-        - no special client requirements
-    Con's:
-        - sender domain is ugly 
-        - flagged as EXTERNAL by Outlook 
-    '''    
-    from azure.communication.email import EmailClient, EmailContent, EmailAddress, EmailMessage, EmailRecipients
-
-    email_cs = config.get("external-services", "xtnotification", "connection-string")
-    email_from = config.get("external-services", "xtnotification", "from")
-
-    client = EmailClient.from_connection_string(email_cs)
-    content = EmailContent(subject=subject, plain_text=body, html=body)
-
-    to_addr_list = [EmailAddress(email=to) for to in to_list]
-    cc_addr_list = [EmailAddress(email=cc) for cc in cc_list]
-
-    message = EmailMessage(sender=email_from, content=content,
-        recipients=EmailRecipients(to=to_addr_list, cc=cc_addr_list))
-
-    response = client.send(message)
-    return response
+    return value
