@@ -16,6 +16,7 @@ import importlib
 from xtlib import qfe
 from xtlib import utils
 from xtlib import errors
+from xtlib import cmd_utils
 from xtlib import constants
 from xtlib import file_utils
 
@@ -28,7 +29,7 @@ logger = logging.getLogger(__name__)
 # global 
 orig_xt_cmd = None
 
-def get_fn_local_config(args):
+def get_fn_local_config(cmd):
     '''
     gets path to local config file (specified on cmd line or defaulting to ./xt_config.yaml)
     '''
@@ -36,8 +37,7 @@ def get_fn_local_config(args):
     fn = os.path.join(".", constants.CONFIG_FN)
 
     # is config file specified by --config option or as a run command with .yaml file script?
-    cmd = " ".join(args)
-    parts = utils.cmd_split(cmd)
+    parts = cmd_utils.xt_cmd_split(cmd)
     found_run = False
 
     for i, part in enumerate(parts):
@@ -81,7 +81,9 @@ def get_fn_local_config(args):
 
     return fn
 
-def process_template(config, args):
+def process_template(config, cmd):
+    args = cmd_utils.xt_cmd_split(cmd)
+
     template_name = args[0][1:]
     args = args[1:]
 
@@ -114,34 +116,10 @@ def process_template(config, args):
 
     return args
 
-def main(cmd=None, new_start_time=None, capture_output=False, basic_mode=False, raise_syntax_exception=True):
+def main(cmd, new_start_time=None, capture_output=False, basic_mode=False, raise_syntax_exception=True):
     '''
     Parse and execute the specified cmd.
     '''
-    if new_start_time:
-        global xt_start_time
-        xt_start_time = new_start_time
-
-    global orig_xt_cmd
-
-    if cmd:
-        orig_xt_cmd = cmd
-        cmd = cmd.strip()
-
-        if cmd.startswith("xt "):
-            cmd = cmd[3:]
-        elif cmd == "xt":
-            cmd = ""
-
-        args = utils.cmd_split(cmd)
-
-        # remove empty args
-        args = [arg for arg in args if arg]
-    else:
-        # if caller did not supply cmd
-        orig_xt_cmd = " ".join(sys.argv)
-        args = sys.argv[1:]
-   
     # when executing multiple commands, reset the feedback for each command
     feedback.reset_feedback()
 
@@ -149,7 +127,7 @@ def main(cmd=None, new_start_time=None, capture_output=False, basic_mode=False,
     console.diag("in xt_cmds.main")
 
     #console.print("config=", config)
-    fn_local_config = get_fn_local_config(args)
+    fn_local_config = get_fn_local_config(cmd)
 
     impl_shared = ImplShared()
     config = impl_shared.init_config(fn_local_config)
@@ -172,8 +150,11 @@ def main(cmd=None, new_start_time=None, capture_output=False, basic_mode=False,
             impl.set_basic_mode(basic_mode)
 
     # process template invocations
-    if args and args[0].startswith("@"):
-        args = process_template(config, args)
+    if cmd and cmd.startswith("xt "):
+        cmd = cmd[3:].strip()
+
+    if cmd.startswith("@"):
+        cmd = process_template(config, cmd)
 
     # this parses args and calls the correct command function with its args and options correctly set.
     # the config object supplies the default value for most options and flags.
@@ -219,16 +200,16 @@ def main(cmd=None, new_start_time=None, capture_output=False, basic_mode=False,
     dispatcher.hide_commands(hide_commands)
 
     # expand symbols like $lastjob, $lastrun
-    impl_shared.expand_xt_symbols(args)
+    cmd = impl_shared.expand_xt_symbols(cmd)
 
     # this is the NORMAL outer exeception handling block, but
     # also see the client/server exception handling in xt_run.py
     try:
-        text = dispatcher.dispatch(args, capture_output=capture_output, raise_syntax_exception=raise_syntax_exception)  
+        text = dispatcher.dispatch(cmd, capture_output=capture_output, raise_syntax_exception=raise_syntax_exception)  
     except BaseException as ex:
         #console.print("in Exception Handler: utils.show_stack_trace=", utils.show_stack_trace)
         # does user want a stack-trace?
-        logger.exception("Error during displatcher.dispatch, args={}".format(args))
+        logger.exception("Error during displatcher.dispatch, cmd={}".format(cmd))
 
         exc_type, exc_value, exc_traceback = sys.exc_info()
         errors.process_exception(exc_type, exc_value, exc_traceback)
